Module threshold_decoder

Module threshold_decoder 

Threshold-based topology decoder for cognitive state classification.

Structs

ThresholdDecoder
Decode cognitive states from topology metrics using learned thresholds.
TopologyThreshold
Threshold ranges for topology metrics associated with a cognitive state.