Threshold-based topology decoder for cognitive state classification.
Structs
- Threshold
Decoder - Decode cognitive states from topology metrics using learned thresholds.
- Topology
Threshold - Threshold ranges for topology metrics associated with a cognitive state.